Struct clucolor::writer::cluColorWriter [−][src]
pub struct cluColorWriter<C: cluColor> { /* fields omitted */ }
Lightweight wrap for generalized color type.
Methods
impl<C: cluColor> cluColorWriter<C>[src]
impl<C: cluColor> cluColorWriter<C>pub fn new() -> cluColorWriter<C>[src]
pub fn new() -> cluColorWriter<C>pub fn raw_color<'a>(&self) -> &'a str[src]
pub fn raw_color<'a>(&self) -> &'a strpub fn raw_color_b<'a>(&self) -> &'a [u8][src]
pub fn raw_color_b<'a>(&self) -> &'a [u8]pub fn name<'a>(&self) -> &'a str[src]
pub fn name<'a>(&self) -> &'a strpub fn write<'a>(&self, w: &mut Write, buf: &'a [u8]) -> Result<()>[src]
pub fn write<'a>(&self, w: &mut Write, buf: &'a [u8]) -> Result<()>pub fn write_str<'a>(&self, w: &mut Write, str: &'a str) -> Result<()>[src]
pub fn write_str<'a>(&self, w: &mut Write, str: &'a str) -> Result<()>pub fn write_fmt<'a>(&self, w: &mut Write, fmt: Arguments<'a>) -> Result<()>[src]
pub fn write_fmt<'a>(&self, w: &mut Write, fmt: Arguments<'a>) -> Result<()>pub fn writen<'a>(&self, w: &mut Write, buf: &'a [u8]) -> Result<()>[src]
pub fn writen<'a>(&self, w: &mut Write, buf: &'a [u8]) -> Result<()>pub fn writen_str<'a>(&self, w: &mut Write, str: &'a str) -> Result<()>[src]
pub fn writen_str<'a>(&self, w: &mut Write, str: &'a str) -> Result<()>pub fn writen_fmt<'a>(&self, w: &mut Write, fmt: Arguments<'a>) -> Result<()>[src]
pub fn writen_fmt<'a>(&self, w: &mut Write, fmt: Arguments<'a>) -> Result<()>pub fn string_as<'a, A: AsRef<str>>(&self, asref: A) -> String[src]
pub fn string_as<'a, A: AsRef<str>>(&self, asref: A) -> Stringpub fn stringn_as<'a, A: AsRef<str>>(&self, asref: A) -> String[src]
pub fn stringn_as<'a, A: AsRef<str>>(&self, asref: A) -> Stringpub fn string<'a>(&self, str: &'a str) -> String[src]
pub fn string<'a>(&self, str: &'a str) -> Stringpub fn string_fmt<'a>(&self, fmt: Arguments<'a>) -> String[src]
pub fn string_fmt<'a>(&self, fmt: Arguments<'a>) -> Stringpub fn stringn<'a>(&self, str: &'a str) -> String[src]
pub fn stringn<'a>(&self, str: &'a str) -> Stringpub fn stringn_fmt<'a>(&self, fmt: Arguments<'a>) -> String[src]
pub fn stringn_fmt<'a>(&self, fmt: Arguments<'a>) -> StringTrait Implementations
impl<C: Debug + cluColor> Debug for cluColorWriter<C>[src]
impl<C: Debug + cluColor> Debug for cluColorWriter<C>fn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl<C: Clone + cluColor> Clone for cluColorWriter<C>[src]
impl<C: Clone + cluColor> Clone for cluColorWriter<C>fn clone(&self) -> cluColorWriter<C>[src]
fn clone(&self) -> cluColorWriter<C>Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl<C: Eq + cluColor> Eq for cluColorWriter<C>[src]
impl<C: Eq + cluColor> Eq for cluColorWriter<C>impl<C: Hash + cluColor> Hash for cluColorWriter<C>[src]
impl<C: Hash + cluColor> Hash for cluColorWriter<C>fn hash<__HC: Hasher>(&self, state: &mut __HC)[src]
fn hash<__HC: Hasher>(&self, state: &mut __HC)Feeds this value into the given [Hasher]. Read more
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, 1.3.0[src]
fn hash_slice<H>(data: &[Self], state: &mut H) where
H: Hasher, Feeds a slice of this type into the given [Hasher]. Read more
impl<C: Ord + cluColor> Ord for cluColorWriter<C>[src]
impl<C: Ord + cluColor> Ord for cluColorWriter<C>fn cmp(&self, other: &cluColorWriter<C>) -> Ordering[src]
fn cmp(&self, other: &cluColorWriter<C>) -> OrderingThis method returns an Ordering between self and other. Read more
fn max(self, other: Self) -> Self1.21.0[src]
fn max(self, other: Self) -> SelfCompares and returns the maximum of two values. Read more
fn min(self, other: Self) -> Self1.21.0[src]
fn min(self, other: Self) -> SelfCompares and returns the minimum of two values. Read more
impl<C: PartialEq + cluColor> PartialEq for cluColorWriter<C>[src]
impl<C: PartialEq + cluColor> PartialEq for cluColorWriter<C>fn eq(&self, other: &cluColorWriter<C>) -> bool[src]
fn eq(&self, other: &cluColorWriter<C>) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &cluColorWriter<C>) -> bool[src]
fn ne(&self, other: &cluColorWriter<C>) -> boolThis method tests for !=.
impl<C: PartialOrd + cluColor> PartialOrd for cluColorWriter<C>[src]
impl<C: PartialOrd + cluColor> PartialOrd for cluColorWriter<C>fn partial_cmp(&self, other: &cluColorWriter<C>) -> Option<Ordering>[src]
fn partial_cmp(&self, other: &cluColorWriter<C>) -> Option<Ordering>This method returns an ordering between self and other values if one exists. Read more
fn lt(&self, other: &cluColorWriter<C>) -> bool[src]
fn lt(&self, other: &cluColorWriter<C>) -> boolThis method tests less than (for self and other) and is used by the < operator. Read more
fn le(&self, other: &cluColorWriter<C>) -> bool[src]
fn le(&self, other: &cluColorWriter<C>) -> boolThis method tests less than or equal to (for self and other) and is used by the <= operator. Read more
fn gt(&self, other: &cluColorWriter<C>) -> bool[src]
fn gt(&self, other: &cluColorWriter<C>) -> boolThis method tests greater than (for self and other) and is used by the > operator. Read more
fn ge(&self, other: &cluColorWriter<C>) -> bool[src]
fn ge(&self, other: &cluColorWriter<C>) -> boolThis method tests greater than or equal to (for self and other) and is used by the >= operator. Read more
impl<C: cluColor> Display for cluColorWriter<C>[src]
impl<C: cluColor> Display for cluColorWriter<C>Auto Trait Implementations
impl<C> Send for cluColorWriter<C> where
C: Send,
impl<C> Send for cluColorWriter<C> where
C: Send, impl<C> Sync for cluColorWriter<C> where
C: Sync,
impl<C> Sync for cluColorWriter<C> where
C: Sync,